@@ -184,7 +184,7 @@ static int filter_tags(bam_seq_t *s, char *aux_filter, int keep) {
 
 static void usage(FILE *fp) {
     fprintf(fp, "  -=- sCRAMble -=-     version %s\n", IOLIB_VERSION);
-    fprintf(fp, "Author: James Bonfield, Wellcome Trust Sanger Institute. 2013-2020\n\n");
+    fprintf(fp, "Author: James Bonfield, Wellcome Trust Sanger Institute. 2013-2022\n\n");
 
     fprintf(fp, "Usage:    scramble [options] [input_file [output_file]]\n");
 
@@ -500,10 +500,14 @@ int main(int argc, char **argv) {
 	return 1;
     }
 
-    if (cram_default_version() > 300) {
+    if (cram_default_version() >= 400) {
 	fprintf(stderr, "\nWARNING: this version of CRAM is not a recognised GA4GH standard.\n"
 		"Note this CRAM version is a technology demonstration only.\n"
 		"Future versions of Scramble may not be able to read these files.\n\n");
+    } else if (cram_default_version() > 300) {
+	fprintf(stderr, "\nWARNING: this version of CRAM has yet to be formally signed off.\n"
+		"CRAM 3.1 has multiple implementations that have been cross-validated, but\n"
+		"the specification document has not yet been accepted as an official standard.\n\n");
     }
 
     if (argc - optind > 2) {
@@ -581,7 +585,7 @@ int main(int argc, char **argv) {
     if (embed_ref) {
 	if (scram_get_header(in)->sort_order == ORDER_NAME ||
 	    scram_get_header(in)->sort_order == ORDER_UNSORTED) {
-	    fprintf(stderr, "Embeded reference with non-coordinate sorted data is "
+	    fprintf(stderr, "Embedded reference with non-coordinate sorted data is "
 		    "not supported.\nUsing -x for no-ref instead.\n");
 	    if (scram_set_option(out, CRAM_OPT_NO_REF, 1))
 		return 1;
@@ -594,7 +598,7 @@ int main(int argc, char **argv) {
     if (embed_cons) {
 	if (scram_get_header(in)->sort_order == ORDER_NAME ||
 	    scram_get_header(in)->sort_order == ORDER_UNSORTED) {
-	    fprintf(stderr, "Embeded consensus with non-coordinate sorted data is "
+	    fprintf(stderr, "Embedded consensus with non-coordinate sorted data is "
 		    "not supported.\n");
 	} else {
 	    if (scram_set_option(out, CRAM_OPT_EMBED_CONS, embed_cons))
